<?php

/**
 * Disable WebP
 * 
 * @package disable-webp
 * @author URBAN BASE <info@urban-base.net>
 * @copyright 2022 Mario Jacob
 * @license GPLv3
 * 
 * @wordpress-plugin
 * Plugin Name:         Disable WebP
 * Plugin URI:          https://github.com/mariojacob/disable-webp
 * Description:         A small plugin to disable the new WebP standard in the settings.
 * Version:             1.0.3
 * Requires at least:   5.8
 * Requires PHP:        7.2
 * Author:              URBAN BASE
 * Author URI:          https://urban-base.net/?utm_source=ubdw_author_uri
 * Text Domain:         disable-webp
 * Domain Path:         /languages
 * License:             GPLv3
 * License URI:         https://www.gnu.org/licenses/quick-guide-gplv3
 */

if (!defined('ABSPATH'))
    die;

define('UBDW__TITLE', 'Disable WebP');
define('UBDW__SLUG', 'disable-webp');
define('UBDW__VERSION', '1.0.3');

load_plugin_textdomain('ubdw', false, dirname(plugin_basename(__FILE__)) . '/languages');

if (empty(get_option('ubdw_disable_webp')))
    add_option('ubdw_disable_webp', 'on');

if (get_option('ubdw_disable_webp') == 'on')
    add_filter('wp_upload_image_mime_transforms', '__return_empty_array');

function ubdw_register_options_page()
{
    add_options_page(UBDW__TITLE, esc_html__('Disable WebP', 'disable-webp'), 'manage_options', UBDW__SLUG, 'ubdw_options_page');
}
add_action('admin_menu', 'ubdw_register_options_page');

function ubdw_options_page()
{
    if (isset($_POST['submit']) && wp_verify_nonce($_POST['nonce'], 'save-ubdw-settings')) {
        if ($_POST['disable-webp'] == 'on')
            update_option('ubdw_disable_webp', 'on');
        else
            update_option('ubdw_disable_webp', '');
    }
?>
    <div class="wrap">
        <h1 class="wp-heading-inline"><?php echo UBDW__TITLE; ?></h1>
        <hr class="wp-header-end">
        <br>
        <div class="postbox">
            <div class="inside">
                <p><?php echo esc_html__('In WordPress 6.1, a WebP version is generated by default when an image is uploaded and displayed in the frontend.', 'disable-webp'); ?></p>
                <p><?php echo esc_html__('The WebP format generally compresses the images well.', 'disable-webp') ?></p>
                <p><?php echo esc_html__('But in certain cases the WebP version can be larger than the original image.', 'disable-webp'); ?></p>
                <p><?php echo esc_html__('If WebP causes problems on your website, you can disable this function here.', 'disable-webp'); ?></p>
                <form action="" method="post">
                    <input type="checkbox" name="disable-webp" <?php if (get_option('ubdw_disable_webp') == 'on') {
                                                                    echo 'checked="checked"';
                                                                } ?>>
                    <b><?php echo esc_html__('Disable WebP', 'disable-webp'); ?></b>
                    <br><br>
                    <input type="hidden" name="nonce" value="<?php echo wp_create_nonce('save-ubdw-settings'); ?>">
                    <input class="button-primary" type="submit" name="submit" value="<?php echo esc_html__('Save changes', 'disable-webp'); ?>">
                </form>
            </div>
        </div>
        <div class="postbox">
            <div class="inside">
                <p><b><?php echo UBDW__TITLE; ?> v<?php echo UBDW__VERSION; ?></b></p>
                <p><?php echo esc_html__('If you like', 'disable-webp'); ?> <?php echo UBDW__TITLE; ?>, <?php echo esc_html__('then write a', 'disable-webp'); ?> <a href="https://wordpress.org/support/plugin/disable-webp/reviews/?filter=5#postform" target="_blank" title="<?php echo UBDW__TITLE; ?> rating">★★★★★ <?php echo esc_html__('rating', 'disable-webp'); ?></a>. <?php echo esc_html__('You would help me a lot to make the plugin known.', 'disable-webp'); ?></p>
            </div>
        </div>
    </div>
<?php
}
